@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::AdditionalValidationChecks;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Email::Valid;
 use Scalar::Util qw(looks_like_number);
@@ -230,6 +230,24 @@ sub register {
 
         return $value !~ $regex;
     });
+
+    $validator->add_check( between => sub {
+        my $op = (looks_like_number( $_[3] ) and looks_like_number( $_[4] ) ) ? 'n' : 's';
+
+        my $result;
+        if ( $op eq 'n' ) {
+            $result = $_[2] < $_[3] || $_[2] > $_[4];
+        }
+        else {
+            $result = (
+                ( ( $_[2] cmp $_[3] ) == -1 ) ||
+                ( ( $_[4] cmp $_[2] ) == -1 )
+            );
+        }
+
+        return $result;
+    });
+
 }
 
 1;
@@ -246,7 +264,7 @@ Mojolicious::Plugin::AdditionalValidationChecks
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
